@@ -47,32 +47,32 @@ var searchData=
   ['midirpndetector_44',['MidiRPNDetector',['../classMidiRPNDetector.html',1,'']]],
   ['midirpngenerator_45',['MidiRPNGenerator',['../classMidiRPNGenerator.html',1,'']]],
   ['midirpnmessage_46',['MidiRPNMessage',['../structMidiRPNMessage.html',1,'']]],
-  ['mimetypetable_47',['MimeTypeTable',['../structMimeTypeTable.html',1,'']]],
-  ['minandmax_48',['MinAndMax',['../structAccessibilityValueInterface_1_1AccessibleValueRange_1_1MinAndMax.html',1,'AccessibilityValueInterface::AccessibleValueRange']]],
-  ['mixeraudiosource_49',['MixerAudioSource',['../classMixerAudioSource.html',1,'']]],
-  ['modalcallbackfunction_50',['ModalCallbackFunction',['../classModalCallbackFunction.html',1,'']]],
-  ['modalcomponentmanager_51',['ModalComponentManager',['../classModalComponentManager.html',1,'']]],
-  ['modifierkeys_52',['ModifierKeys',['../classModifierKeys.html',1,'']]],
-  ['mountedvolumelistchangedetector_53',['MountedVolumeListChangeDetector',['../classMountedVolumeListChangeDetector.html',1,'']]],
-  ['mousecursor_54',['MouseCursor',['../classMouseCursor.html',1,'']]],
-  ['mouseevent_55',['MouseEvent',['../classMouseEvent.html',1,'']]],
-  ['mouseinactivitydetector_56',['MouseInactivityDetector',['../classMouseInactivityDetector.html',1,'']]],
-  ['mouseinputsource_57',['MouseInputSource',['../classMouseInputSource.html',1,'']]],
-  ['mouselistener_58',['MouseListener',['../classMouseListener.html',1,'']]],
-  ['mousewheeldetails_59',['MouseWheelDetails',['../structMouseWheelDetails.html',1,'']]],
-  ['mp3audioformat_60',['MP3AudioFormat',['../classMP3AudioFormat.html',1,'']]],
-  ['mpechannelassigner_61',['MPEChannelAssigner',['../classMPEChannelAssigner.html',1,'']]],
-  ['mpechannelremapper_62',['MPEChannelRemapper',['../classMPEChannelRemapper.html',1,'']]],
-  ['mpeinstrument_63',['MPEInstrument',['../classMPEInstrument.html',1,'']]],
-  ['mpekeyboardcomponent_64',['MPEKeyboardComponent',['../classMPEKeyboardComponent.html',1,'']]],
-  ['mpemessages_65',['MPEMessages',['../classMPEMessages.html',1,'']]],
-  ['mpenote_66',['MPENote',['../structMPENote.html',1,'']]],
-  ['mpesynthesiser_67',['MPESynthesiser',['../classMPESynthesiser.html',1,'']]],
-  ['mpesynthesiserbase_68',['MPESynthesiserBase',['../structMPESynthesiserBase.html',1,'']]],
-  ['mpesynthesiservoice_69',['MPESynthesiserVoice',['../classMPESynthesiserVoice.html',1,'']]],
-  ['mpevalue_70',['MPEValue',['../classMPEValue.html',1,'']]],
-  ['mpezone_71',['MPEZone',['../structMPEZone.html',1,'']]],
-  ['mpezonelayout_72',['MPEZoneLayout',['../classMPEZoneLayout.html',1,'']]],
+  ['minandmax_47',['MinAndMax',['../structAccessibilityValueInterface_1_1AccessibleValueRange_1_1MinAndMax.html',1,'AccessibilityValueInterface::AccessibleValueRange']]],
+  ['mixeraudiosource_48',['MixerAudioSource',['../classMixerAudioSource.html',1,'']]],
+  ['modalcallbackfunction_49',['ModalCallbackFunction',['../classModalCallbackFunction.html',1,'']]],
+  ['modalcomponentmanager_50',['ModalComponentManager',['../classModalComponentManager.html',1,'']]],
+  ['modifierkeys_51',['ModifierKeys',['../classModifierKeys.html',1,'']]],
+  ['mountedvolumelistchangedetector_52',['MountedVolumeListChangeDetector',['../classMountedVolumeListChangeDetector.html',1,'']]],
+  ['mousecursor_53',['MouseCursor',['../classMouseCursor.html',1,'']]],
+  ['mouseevent_54',['MouseEvent',['../classMouseEvent.html',1,'']]],
+  ['mouseinactivitydetector_55',['MouseInactivityDetector',['../classMouseInactivityDetector.html',1,'']]],
+  ['mouseinputsource_56',['MouseInputSource',['../classMouseInputSource.html',1,'']]],
+  ['mouselistener_57',['MouseListener',['../classMouseListener.html',1,'']]],
+  ['mousewheeldetails_58',['MouseWheelDetails',['../structMouseWheelDetails.html',1,'']]],
+  ['mp3audioformat_59',['MP3AudioFormat',['../classMP3AudioFormat.html',1,'']]],
+  ['mpechannelassigner_60',['MPEChannelAssigner',['../classMPEChannelAssigner.html',1,'']]],
+  ['mpechannelremapper_61',['MPEChannelRemapper',['../classMPEChannelRemapper.html',1,'']]],
+  ['mpeinstrument_62',['MPEInstrument',['../classMPEInstrument.html',1,'']]],
+  ['mpekeyboardcomponent_63',['MPEKeyboardComponent',['../classMPEKeyboardComponent.html',1,'']]],
+  ['mpemessages_64',['MPEMessages',['../classMPEMessages.html',1,'']]],
+  ['mpenote_65',['MPENote',['../structMPENote.html',1,'']]],
+  ['mpesynthesiser_66',['MPESynthesiser',['../classMPESynthesiser.html',1,'']]],
+  ['mpesynthesiserbase_67',['MPESynthesiserBase',['../structMPESynthesiserBase.html',1,'']]],
+  ['mpesynthesiservoice_68',['MPESynthesiserVoice',['../classMPESynthesiserVoice.html',1,'']]],
+  ['mpevalue_69',['MPEValue',['../classMPEValue.html',1,'']]],
+  ['mpezone_70',['MPEZone',['../structMPEZone.html',1,'']]],
+  ['mpezonelayout_71',['MPEZoneLayout',['../classMPEZoneLayout.html',1,'']]],
+  ['muid_72',['MUID',['../classjuce_1_1midi__ci_1_1MUID.html',1,'juce::midi_ci']]],
   ['multichoicepropertycomponent_73',['MultiChoicePropertyComponent',['../classMultiChoicePropertyComponent.html',1,'']]],
   ['multidocumentpanel_74',['MultiDocumentPanel',['../classMultiDocumentPanel.html',1,'']]],
   ['multidocumentpanelwindow_75',['MultiDocumentPanelWindow',['../classMultiDocumentPanelWindow.html',1,'']]],
