@@ -8,13 +8,13 @@ var searchData=
   ['specialitemids_5',['SpecialItemIds',['../classToolbarItemFactory.html#a415ffaa38b6306574ad6777ccf6d2ac4',1,'ToolbarItemFactory']]],
   ['speciallocationtype_6',['SpecialLocationType',['../classFile.html#a3e19cafabb03c5838160263a6e76313d',1,'File']]],
   ['standardcursortype_7',['StandardCursorType',['../classMouseCursor.html#a5de22a8c3eb06827ac11352e76eb9a97',1,'MouseCursor']]],
-  ['statevariablefiltertype_8',['StateVariableFilterType',['../namespacedsp_1_1StateVariableFilter.html#ae6c163b1aed0e44e5b19e9cc7f02926b',1,'dsp::StateVariableFilter']]],
-  ['statevariabletptfiltertype_9',['StateVariableTPTFilterType',['../namespacedsp.html#a2812ed585354d3af60168fd6a9c14079',1,'dsp']]],
-  ['status_10',['Status',['../structInAppPurchases_1_1Download.html#a5291a850795414d13ff21f08de0f5a7d',1,'InAppPurchases::Download']]],
-  ['stereo_11',['Stereo',['../classdsp_1_1Convolution.html#a7ac3ad9411cff6c9c97b0ac86de26ebe',1,'dsp::Convolution']]],
+  ['statevariablefiltertype_8',['StateVariableFilterType',['../namespacejuce_1_1dsp_1_1StateVariableFilter.html#af6152e4d91c6e4cf5b9eee15ec50e6c2',1,'juce::dsp::StateVariableFilter']]],
+  ['statevariabletptfiltertype_9',['StateVariableTPTFilterType',['../namespacejuce_1_1dsp.html#ae3730a1ca71c46b7d035f4f3b72f808d',1,'juce::dsp']]],
+  ['status_10',['status',['../structInAppPurchases_1_1Download.html#a5291a850795414d13ff21f08de0f5a7d',1,'InAppPurchases::Download::Status'],['../classjuce_1_1midi__ci_1_1Parser.html#ac97b82f818246afaf7b14477feae3384',1,'juce::midi_ci::Parser::Status']]],
+  ['stereo_11',['Stereo',['../classjuce_1_1dsp_1_1Convolution.html#aafb1dce86f6ceae0532adf83497a151b',1,'juce::dsp::Convolution']]],
   ['storageformat_12',['StorageFormat',['../classPropertiesFile.html#ac4d1ac9a6b624f7e0de7787de46dc05e',1,'PropertiesFile']]],
   ['streamflags_13',['StreamFlags',['../classChildProcess.html#a9e7be158550b4d2a470e4cceef501892',1,'ChildProcess']]],
   ['streamkind_14',['StreamKind',['../classCoreAudioFormat.html#a892e81f36a7ca376a0a83cfba0351e2f',1,'CoreAudioFormat']]],
-  ['style_15',['Style',['../classProgressBar.html#ab8e61e7e73ef5de4a9a28e5975d40beb',1,'ProgressBar::Style'],['../classComponentPeer.html#af3f12e11d020aae24801145f0238e8ac',1,'ComponentPeer::Style'],['../structPushNotifications_1_1Notification_1_1Action.html#a8694375bdc3dd690cb12a97cab9570c0',1,'PushNotifications::Notification::Action::Style']]],
+  ['style_15',['style',['../classProgressBar.html#ab8e61e7e73ef5de4a9a28e5975d40beb',1,'ProgressBar::Style'],['../classComponentPeer.html#af3f12e11d020aae24801145f0238e8ac',1,'ComponentPeer::Style'],['../structPushNotifications_1_1Notification_1_1Action.html#a8694375bdc3dd690cb12a97cab9570c0',1,'PushNotifications::Notification::Action::Style']]],
   ['styleflags_16',['StyleFlags',['../classComponentPeer.html#a94a21f91c61f8211774d6f43243a6ddc',1,'ComponentPeer']]]
 ];
